==> sources_fancymenu_fabric_3.8.0_MC_1.19.2.jar: de/keksuccino/fancymenu/customization/placeholder/placeholders/client/WorldLoadProgressPlaceholder.java <==
package de.keksuccino.fancymenu.customization.placeholder.placeholders.client;

import de.keksuccino.fancymenu.customization.placeholder.DeserializedPlaceholderString;
import de.keksuccino.fancymenu.customization.placeholder.Placeholder;
import de.keksuccino.fancymenu.mixin.mixins.common.client.IMixinLevelLoadingScreen;
import de.keksuccino.fancymenu.mixin.mixins.common.client.IMixinProgressScreen;
import de.keksuccino.fancymenu.util.LocalizationUtils;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import java.util.Arrays;
import java.util.List;
import net.minecraft.class_1074;
import net.minecraft.class_310;
import net.minecraft.class_3928;
import net.minecraft.class_435;
import net.minecraft.class_437;

public class WorldLoadProgressPlaceholder extends Placeholder {

    public WorldLoadProgressPlaceholder() {
        super("world_load_progress");
    }

    @Override
    public boolean canRunAsync() {
        return false;
    }

    @Override
    public String getReplacementFor(DeserializedPlaceholderString dps) {
        class_437 s = class_310.method_1551().field_1755;
        if (s instanceof class_435 p) {
            return "" + ((IMixinProgressScreen)p).getProgressFancyMenu();
        }
        if (s instanceof class_3928 l) {
            return "" + ((IMixinLevelLoadingScreen)l).getProgressListenerFancyMenu().method_17679();
        }
        return "0";
    }

    @Override
    public @Nullable List<String> getValueNames() {
        return null;
    }

    @Override
    public @NotNull String getDisplayName() {
        return class_1074.method_4662("fancymenu.placeholders.world_load_progress");
    }

    @Override
    public List<String> getDescription() {
        return Arrays.asList(LocalizationUtils.splitLocalizedStringLines("fancymenu.placeholders.world_load_progress.desc"));
    }

    @Override
    public String getCategory() {
        return class_1074.method_4662("fancymenu.requirements.categories.client");
    }

    @Override
    public @NotNull DeserializedPlaceholderString getDefaultPlaceholderString() {
        DeserializedPlaceholderString dps = new DeserializedPlaceholderString();
        dps.placeholderIdentifier = this.getIdentifier();
        return dps;
    }

}

==> sources_fancymenu_fabric_3.8.1_MC_1.21.10.jar: de/keksuccino/fancymenu/customization/placeholder/placeholders/client/WorldLoadProgressPlaceholder.java <==
package de.keksuccino.fancymenu.customization.placeholder.placeholders.client;

import de.keksuccino.fancymenu.customization.placeholder.DeserializedPlaceholderString;
import de.keksuccino.fancymenu.customization.placeholder.Placeholder;
import de.keksuccino.fancymenu.mixin.mixins.common.client.IMixinLevelLoadingScreen;
import de.keksuccino.fancymenu.mixin.mixins.common.client.IMixinProgressScreen;
import de.keksuccino.fancymenu.util.LocalizationUtils;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import java.util.Arrays;
import java.util.List;
import net.minecraft.class_1074;
import net.minecraft.class_310;
import net.minecraft.class_3928;
import net.minecraft.class_435;
import net.minecraft.class_437;

public class WorldLoadProgressPlaceholder extends Placeholder {

    public WorldLoadProgressPlaceholder() {
        super("world_load_progress");
    }

    @Override
    public boolean canRunAsync() {
        return false;
    }

    @Override
    public String getReplacementFor(DeserializedPlaceholderString dps) {
        class_437 s = class_310.method_1551().field_1755;
        if (s instanceof class_435 p) {
            return "" + ((IMixinProgressScreen)p).getProgressFancyMenu();
        }
        if (s instanceof class_3928 l) {
            return "" + (int)(((IMixinLevelLoadingScreen)l).get_loadTracker_FancyMenu().method_72905() * 100.0F);
        }
        return "0";
    }

    @Override
    public @Nullable List<String> getValueNames() {
        return null;
    }

    @Override
    public @NotNull String getDisplayName() {
        return class_1074.method_4662("fancymenu.placeholders.world_load_progress");
    }

    @Override
    public List<String> getDescription() {
        return Arrays.asList(LocalizationUtils.splitLocalizedStringLines("fancymenu.placeholders.world_load_progress.desc"));
    }

    @Override
    public String getCategory() {
        return class_1074.method_4662("fancymenu.requirements.categories.client");
    }

    @Override
    public @NotNull DeserializedPlaceholderString getDefaultPlaceholderString() {
        DeserializedPlaceholderString dps = new DeserializedPlaceholderString();
        dps.placeholderIdentifier = this.getIdentifier();
        return dps;
    }

}
